Tutorial on TorchTrainer class
=========================================

.. include:: ../../../tutorials/distributed-ml/torch-tutorial-2-trainer-class/README.md
   :parser: myst_parser.sphinx_


train.py
++++++++

.. literalinclude:: ../../../tutorials/distributed-ml/torch-tutorial-2-trainer-class/train.py
   :language: python